LocalStorageConfig

Struct LocalStorageConfig 

pub struct LocalStorageConfig {
    pub flush_attempt_threshold: usize,
    pub flush_threshold: usize,
}

Fields

flush_attempt_threshold: usize

Soft threshold for flushing. Will flush automatically only if global buffer is available at the moment.

Default: 32KB

flush_threshold: usize

Max capacity of the thread-local storage buffer in bytes. After reaching this threshold, the buffer will be flushed to the global storage. Thread will be blocked until the flushing operation is finished.

Default: 1MB

Implementations

Source

impl LocalStorageConfig

pub const fn default() -> Self