LocalStorage

Struct LocalStorage 

pub struct LocalStorage<G: GlobalStorageImpl> { /* private fields */ }

Implementations

Source

impl<G: GlobalStorageImpl> LocalStorage<G>

pub fn new( global_storage_ref: G, thread_info: ThreadInfo, config: LocalStorageConfig, ) -> Self

pub fn event_range_start(&mut self, hash: u32, name: &str) -> RangeStartRepr

pub fn event_range_end( &mut self, range_start: RangeStartRepr, hash: u32, name: &str, )

pub fn event_instant(&mut self, hash: u32, string: &str)

pub fn set_cur_thread_name(&mut self, name: String)

pub fn auto_flush(&mut self)

Check buffer length, and flush if the buffer is full

pub fn flush(&mut self, blocking: bool)

Flush whole event buffer data to the global storage